@@ -1,5 +1,6 @@
 """Parse tree node and pseudo "tag" for output statements."""
 from typing import Any
+from typing import List
 from typing import Optional
 from typing import TextIO
 
@@ -14,7 +15,9 @@ except ImportError:
     # pylint: disable=invalid-name
     soft_str = str  # type: ignore
 
+from liquid.ast import ChildNode
 from liquid.ast import Node
+
 from liquid.context import Context
 from liquid.expression import Expression
 from liquid.parse import expect
@@ -43,7 +46,6 @@ class StatementNode(Node):
     def __repr__(self) -> str:  # pragma: no cover
         return f"StatementNode(tok={self.tok}, expression={self.expression!r})"
 
-    # pylint: disable=no-self-use
     def _to_liquid_string(self, val: Any, autoescape: bool) -> str:
         if isinstance(val, str) or (autoescape and hasattr(val, "__html__")):
             pass
@@ -80,6 +82,9 @@ class StatementNode(Node):
         buffer.write(self._to_liquid_string(val, context.autoescape))
         return None
 
+    def children(self) -> List[ChildNode]:
+        return [ChildNode(linenum=self.tok.linenum, expression=self.expression)]
+
 
 class Statement(Tag):
     """Pseudo "tag" to register output statements with the environment."""
